from test_admin import *
from test_forms import *
from test_listeners import *
from test_managers import *
from test_models import *
from test_settings import *
from test_templatetags import *
from test_signals import *
from test_views import *



from decimal import Decimal
from django.test import TestCase
from ccpages.forms import PagePasswordForm
from ccpages.models import Page


class PageFormTestCases(TestCase):

    def test_silent_fail_if_no_page_supplied(self):
        """If no page is supplied to the form then the KeyError
        is silent"""
        form = PagePasswordForm()

    def test_supply_incorrect_password_and_form_is_invalid(self):
        """If we supply the incorrect password to the form then the
        form will not validate"""
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.password = 'ha'
        page1.status = Page.VISIBLE
        page1.save()
        # make the data
        data = {'password': 'wrong'}
        # make the form
        form = PagePasswordForm(data, page=page1)
        # form is not valid
        self.assertFalse(form.is_valid())

    def test_supply_correct_password_and_form_has_a_hash(self):
        """If we supply the correct password to the form then the
        form will save the hash value"""
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.password = 'ha'
        page1.status = Page.VISIBLE
        page1.save()
        # make the data
        data = {'password': 'ha'}
        # make the form
        form = PagePasswordForm(data, page=page1)
        form.is_valid()
        # form has a hash
        self.assertTrue(form.hash)

    def test_supply_correct_password_and_form_is_valid(self):
        """If we supply the correct password to the form then the
        form will validate"""
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.password = 'ha'
        page1.status = Page.VISIBLE
        page1.save()
        # make the data
        data = {'password': 'ha'}
        # make the form
        form = PagePasswordForm(data, page=page1)
        # form is valid
        self.assertTrue(form.is_valid())




from django.conf import settings

"""The default status for pages. 1 is visible and 0 is hidden"""
CCPAGES_DEFAULT_STATUS = getattr(
            settings,
            'CCPAGES_DEFAULT_STATUS',
            1)

"""Sizes for the images in the PageImage model"""
CCPAGES_IMAGE_SIZES = getattr(
        settings,
        'CCPAGES_IMAGE_SIZES',
        (   (140, 140),
            (240,160),
            (480,320),
            (960,640)))



from django.contrib import messages
from django.core.urlresolvers import reverse
from django.http import HttpResponse, HttpResponseRedirect, Http404
from django.shortcuts import render_to_response, get_object_or_404
from django.template import RequestContext
from ccpages.models import Page
from ccpages.forms import PagePasswordForm


def index(request):
    """the index view returns the first page"""

    try:
        page = Page.custom.default()
    except Page.DoesNotExist:
        raise Http404()

    return HttpResponseRedirect(
            reverse('ccpages:view', args=[page.slug]))

def view(request, slug):
    """returns the page if there is no password.

    - if there is a password and the users session contains
        the correct hash then the page is returned

   - if there is a password and the users session does
       not contain the correct hash then they are redirected
       to the password view"""

    try:
        page = Page.custom.visible()\
                .get(slug=slug)
    except Page.DoesNotExist:
        raise Http404()

    # get the user_hash from the session
    try:
        user_hash = request.session['ccpage_%s_hash' % page.pk]
    except KeyError:
        user_hash = None

    # check the hash if the page is password protected
    password = page.password or ''
    if len(password) > 0 and user_hash != page.hash:
        messages.error(request,
                '"%s" is password protected' % page.title)
        return HttpResponseRedirect(
                reverse('ccpages:password', args=[page.slug]))

    return render_to_response(
            'ccpages/view.html',
            {'page': page},
            RequestContext(request))


def password(request, slug):
    """ process the password for a page"""
    try:
        page = Page.custom.visible().get(slug=slug)
    except Page.DoesNotExist:
        raise Http404()

    # if there is no password for the page redirect back
    if not page.password:
        return HttpResponseRedirect(
                reverse('ccpages:view', args=[page.slug]))
    # make a form
    form = PagePasswordForm()

    # check the post
    if request.method == 'POST':
        form = PagePasswordForm(request.POST, page=page)
        if form.is_valid():
             request.session['ccpage_%s_hash' % page.pk] = form.hash
             return HttpResponseRedirect(
                     reverse('ccpages:view', args=[page.slug]))

    return render_to_response(
            'ccpages/password.html',
            {
                'page': page,
                'form': form },
            RequestContext(request))



import os
from distutils.core import setup
from ccpages import VERSION

root_dir = os.path.dirname(__file__)
if root_dir != '':
    os.chdir(root_dir)

setup(
    name="django-ccpages",
    version=VERSION,
    license = 'BSD 3 Clause',
    description='A lightweight pages application for Django',
    long_description=open('README.rst').read(),
    author='c&c',
    author_email='studio@designcc.co.uk',
    url='https://github.com/designcc/django-ccpages',
    package_data = {
        'ccpages' : [
            'templates/ccpages/*.html',
            'static/ccpages/css/*.css',
            'static/ccpages/test.pdf',
            'static/ccpages/fancybox/source/*.gif',
            'static/ccpages/fancybox/source/*.png',
            'static/ccpages/fancybox/source/*.css',
            'static/ccpages/fancybox/source/*.js',
            'static/ccpages/fancybox/source/*.png',
            'static/ccpages/fancybox/source/helpers/*.png',
            'static/ccpages/fancybox/source/helpers/*.css',
            'static/ccpages/fancybox/source/helpers/*.js',
        ],
    },
    packages=[
        'ccpages',
        'ccpages.templatetags',
        'ccpages.tests'
    ],
    install_requires = [
        'django-mptt',
        'django-ccthumbs',
        'django-ccfiletypes',
        'markdown'])



from django.conf import settings
from django.test import TestCase
from ccpages import settings as c_settings
from ccpages.tests.mock import MockRequest
from ccpages.views import index


class SettingsTest(TestCase):

    def test_default_status(self):
        """default status"""
        original = getattr(settings, 'CCPAGES_DEFAULT_STATUS', None)
        # defaults to 1
        self.assertEqual(1, c_settings.CCPAGES_DEFAULT_STATUS)
        # make it 0 
        settings.CCPAGES_DEFAULT_STATUS = 0
        reload(c_settings)
        self.assertEqual(0, c_settings.CCPAGES_DEFAULT_STATUS)
        # revert it
        setattr(settings, 'CCPAGES_DEFAULT_STATUS', original)



from decimal import Decimal
from django.core.urlresolvers import reverse
from django.http import Http404
from django.test import TestCase
from ccpages.tests.mock import MockRequest
from ccpages.views import index, view, password
from ccpages.models import Page


class ViewTestCases(TestCase):

    def setUp(self):
        # create a reqest factory
        self.rf = MockRequest()

    def test_password_404(self):
        """Any attempt to access a page that doesn't exist returns
        a 404 status code"""
        response = self.client.get(reverse('ccpages:password', args=['asd']))
        self.assertEqual(404, response.status_code)

    def test_password_200(self):
        """The password page responds with a 200 ok"""
        # make a page
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.password = 'wrng'
        page1.status = Page.VISIBLE
        page1.save()
        # make post request and we get a 200
        request = self.rf.get(
                reverse('ccpages:password', args=[page1.slug]))
        response = password(request, page1.slug)
        self.assertEqual(200, response.status_code)

    def test_password_post_incorrect_password(self):
        """When the incorrect password for a page is sent via post
        the users session is updated to include a hash that allows
        access"""
        # make a page
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.password = 'wrng'
        page1.status = Page.VISIBLE
        page1.save()
        # make post request and we get a 200
        request = self.rf.post(
                reverse('ccpages:password', args=[page1.slug]),
                {'password': 'billy-bo-django'})
        response = password(request, page1.slug)
        self.assertEqual(200, response.status_code)

    def test_password_post_correct_password(self):
        """When the correct password for a page is sent via post
        the users session is updated to include a hash that allows
        access"""
        # make a page
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.password = 'billy-bo-django'
        page1.status = Page.VISIBLE
        page1.save()
        # make request and we get a 302
        request = self.rf.post(
                reverse('ccpages:password', args=[page1.slug]),
                {'password': 'billy-bo-django'})
        response = password(request, page1.slug)
        self.assertEqual(302, response.status_code)
        # and now the session has the key and a hash in it
        self.assertEqual(
                request.session['ccpage_1_hash'],
                'c0b0f36ffdfe68518916a0ea9d8a89cd2b4bc586')

    def test_password_redirects_back_if_page_has_no_password(self):
        """if a page has no password and the user attempts to access
        the password page, they are redirected back"""
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.status = Page.VISIBLE
        page1.save()
        # make request and we get a 302
        request = self.rf.get(reverse('ccpages:password', args=[1]))
        response = password(request, page1.slug)
        self.assertEqual(302, response.status_code)
        self.assertEqual(
                response['Location'],
                reverse('ccpages:view', args=[page1.slug]))

    def test_index_no_pages_404(self):
        """if there are no pages then the index returns a 404"""
        request = self.rf.get(reverse('ccpages:index'))
        self.assertRaises(Http404, index, request)

    def test_index_200(self):
        """If there is a default then we get a nice 200"""
        # make a page
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.status = Page.VISIBLE
        page1.save()
        # make request and we get a 200
        request = self.rf.get(reverse('ccpages:index'))
        response = index(request)
        self.assertEqual(302, response.status_code)

    def test_view_404(self):
        """Any attempt to access a page that doesn't exist returns
        a 404 status code"""
        response = self.client.get(reverse('ccpages:view', args=['asd']))
        self.assertEqual(404, response.status_code)

    def test_view_with_correct_hash(self):
        """if a user visits a page with the correct hash in their
        session the view returns a 200 response"""
        # make a page
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.password = 'billy-bo-django'
        page1.status = Page.VISIBLE
        page1.save()
        # make request and we get a 200
        request = self.rf.get(reverse('ccpages:view', args=[page1.slug]))
        hash = 'c0b0f36ffdfe68518916a0ea9d8a89cd2b4bc586'
        request.session['ccpage_1_hash'] = hash
        response = view(request, page1.slug)
        self.assertEqual(200, response.status_code)

    def test_view_200(self):
        """A visible page with no password returns a 200"""
        # make a page
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.status = Page.VISIBLE
        page1.save()
        # make request and we get a 200
        request = self.rf.get(reverse('ccpages:view', args=[1]))
        response = view(request, page1.slug)
        self.assertEqual(200, response.status_code)

    def test_view_password_redirects(self):
        """If there is a page with a password and the user isn't
        authed to view it then it redirects to the view view, but
        with a different url"""
        page1 = Page()
        page1.title = '1'
        page1.slug = '1'
        page1.content = '1'
        page1.order = Decimal('1')
        page1.status = Page.VISIBLE
        page1.password = 'la-ritournelle'
        page1.save()
        # make request and we get a 302
        request = self.rf.get(reverse('ccpages:view', args=[1]))
        response = view(request, page1.slug)
        self.assertEqual(302, response.status_code)
        self.assertEqual(
                response['Location'],
                reverse('ccpages:password', args=[page1.slug]))
